function [tout,ybp,ycosbp,ysinbp,ycosbb,ysinbb,cossym,sinsym] = qamrand(nsym,M,ts,carrierfreq,tr)

%[tout,ybp,ycosbp,ysinbp,ycosbb,ysinbb,cossym,sinsym] = qamrand(nsym,M,ts,carrierfreq,tr)
%
%Function to generate a QAM signal from two randomly generated symbols sequences
%
%Input parameters:
%
%nsym          the number of symbols to be transmitted on each carrier
%M             the number of symbol levels
%ts	       the symbol period
%carrierfreq   the carrier frequency of the cosine and sine modulating waves
%tr            the time resolution of the signal
%
%The function returns:
%
%tout     the time vector for the waveform
%ybp      the overal QAM signal
%ycosbp   the cosine component of the QAM output
%ysinbp   the sine component of the QAM output
%ycosbb   the base-band cosine symbol sequence waveform
%ysinbb   the base-band sine symbol sequence waveform
%cossym   the cosine symbol sequence
%sinsym   the sine sybol sequence

%generate a random sequence of symbols of for the cosine and sine carriers
[cossym,sinsym]=gensym(nsym,M);



%generate baseband cosine and sine waveforms
[t,ycosbb,ysinbb]=genbbnew(cossym,sinsym,M,ts,tr);



%generate the QAM siganl
[tout,ybp,ycosbp,ysinbp]=qammod(t,ycosbb,ysinbb,tr,carrierfreq);

